(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    162356,       4136]
NotebookOptionsPosition[    153127,       4011]
NotebookOutlinePosition[    153540,       4027]
CellTagsIndexPosition[    153497,       4024]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Angular Observables in Beneke 2021", "Title",
 CellChangeTimes->{{3.8709330864232683`*^9, 
  3.870933101570068*^9}},ExpressionUUID->"9c4b7cfd-96e6-4537-935d-\
10cfac86b5e7"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "In", " ", "order", " ", "to", " ", "check", " ", "the", " ", "projection",
     " ", "technique", " ", "for", " ", "the", " ", "angular", " ", 
    "observables", " ", "for", " ", "our", " ", "project"}], ",", " ", 
   RowBox[{
   "we", " ", "here", " ", "reperform", " ", "the", " ", "calculations", " ", 
    "from", " ", "Beneke", " ", "et", " ", 
    RowBox[{"al", ".", " ", 
     RowBox[{"(", "2021", ")"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"<", 
     RowBox[{"https", ":"}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"arxiv", ".", "org"}], "/", "pdf"}], "/", 
      RowBox[{"2102.10060", ".", "pdf"}]}], ">", "."}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.870936854719407*^9, 3.870936891126422*^9}, {
  3.870937264532761*^9, 3.870937276849979*^9}, {3.9329652738400106`*^9, 
  3.932965278108314*^9}},ExpressionUUID->"d1175880-9af7-46d5-8a9b-\
c1aecb0755de"],

Cell[CellGroupData[{

Cell["Basis States for Angular Observable Projection", "Section",
 CellChangeTimes->{{3.870936945987339*^9, 3.870936957673661*^9}, {
  3.8709428578930387`*^9, 
  3.870942861927599*^9}},ExpressionUUID->"b9e2f608-af7d-414b-8e86-\
fb4770a02cc1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Projectors", " ", "for", " ", "the", " ", "angular", " ", "basis"}], ",",
     " ", 
    RowBox[{
     RowBox[{"see", " ", "<", 
      RowBox[{"https", ":"}]}], "//", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"arxiv", ".", "org"}], "/", "pdf"}], "/", 
       RowBox[{"1503.04100", ".", "pdf"}]}], ">", 
      RowBox[{".", " ", "Here"}]}]}], ",", " ", 
    RowBox[{"x", "=", 
     RowBox[{"cos", 
      RowBox[{"(", 
       SubscriptBox["\[Theta]", "1"], ")"}]}]}], ",", " ", 
    RowBox[{"y", "=", 
     RowBox[{"cos", 
      RowBox[{"(", 
       SubscriptBox["\[Theta]", "2"], ")"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"and", " ", "z"}], "=", 
     RowBox[{
      SubscriptBox["\[Theta]", "3"], "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"n_", ",", "x_"}], "]"}], ":=", 
     RowBox[{"LegendreP", "[", 
      RowBox[{"n", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"p2", "[", 
      RowBox[{"n_", ",", "m_", ",", "x_"}], "]"}], ":=", 
     RowBox[{"LegendreP", "[", 
      RowBox[{"n", ",", "m", ",", "x"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{
       "l1_", ",", "l2_", ",", "m_", ",", "x_", ",", "y_", ",", "z_"}], "]"}],
       ":=", 
      RowBox[{
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"l1", "-", 
             RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"l2", "-", 
             RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"l1", "+", 
             RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"l2", "+", 
             RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]}]]], 
       SuperscriptBox[
        RowBox[{"p", "[", 
         RowBox[{"l1", ",", "x"}], "]"}], 
        RowBox[{"Abs", "[", "m", "]"}]], 
       SuperscriptBox[
        RowBox[{"p", "[", 
         RowBox[{"l2", ",", "y"}], "]"}], 
        RowBox[{"Abs", "[", "m", "]"}]], "*", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"m", ">", "0"}], ",", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"Abs", "[", "m", "]"}], "*", "z"}], "]"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"m", "<", "0"}], ",", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"Abs", "[", "m", "]"}], "*", "z"}], "]"}], ",", "1"}], 
          "]"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fDual", "[", 
       RowBox[{
       "l1_", ",", "l2_", ",", "m_", ",", "x_", ",", "y_", ",", "z_"}], "]"}],
       ":=", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "l1"}], "+", "1"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "l2"}], "+", "1"}], ")"}]}], 
        RowBox[{"8", "\[Pi]"}]], 
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"l1", "-", "m"}], ")"}], "!"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"l2", "-", "m"}], ")"}], "!"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"l1", "+", "m"}], ")"}], "!"}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"l2", "+", "m"}], ")"}], "!"}]}]]], 
       SuperscriptBox[
        RowBox[{"p", "[", 
         RowBox[{"l1", ",", "x"}], "]"}], "m"], 
       SuperscriptBox[
        RowBox[{"p", "[", 
         RowBox[{"l2", ",", "y"}], "]"}], "m"], "*", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"m", ">", "0"}], ",", 
         RowBox[{"2", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"Abs", "[", "m", "]"}], "*", "z"}], "]"}]}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"m", "<", "0"}], ",", 
           RowBox[{"2", 
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"Abs", "[", "m", "]"}], "*", "z"}], "]"}]}], ",", "1"}],
           "]"}]}], "]"}]}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fBasis", "[", 
      RowBox[{"l1_", ",", "l2_", ",", "m_", ",", "x_", ",", "y_", ",", "z_"}],
       "]"}], ":=", 
     RowBox[{
      SqrtBox[
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l1", "-", 
            RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l2", "-", 
            RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l1", "+", 
            RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l2", "+", 
            RowBox[{"Abs", "[", "m", "]"}]}], ")"}], "!"}]}]]], 
      RowBox[{"p2", "[", 
       RowBox[{"l1", ",", 
        RowBox[{"Abs", "[", "m", "]"}], ",", "x"}], "]"}], 
      RowBox[{"p2", "[", 
       RowBox[{"l2", ",", 
        RowBox[{"Abs", "[", "m", "]"}], ",", "y"}], "]"}], "*", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"m", ">", "0"}], ",", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"Abs", "[", "m", "]"}], "*", "z"}], "]"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"m", "<", "0"}], ",", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"Abs", "[", "m", "]"}], "*", "z"}], "]"}], ",", "1"}], 
         "]"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fDualBasis", "[", 
      RowBox[{"l1_", ",", "l2_", ",", "m_", ",", "x_", ",", "y_", ",", "z_"}],
       "]"}], ":=", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "l1"}], "+", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "l2"}], "+", "1"}], ")"}]}], 
       RowBox[{"8", "\[Pi]"}]], 
      SqrtBox[
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l1", "-", "m"}], ")"}], "!"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l2", "-", "m"}], ")"}], "!"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l1", "+", "m"}], ")"}], "!"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l2", "+", "m"}], ")"}], "!"}]}]]], 
      RowBox[{"p2", "[", 
       RowBox[{"l1", ",", "m", ",", "x"}], "]"}], 
      RowBox[{"p2", "[", 
       RowBox[{"l2", ",", "m", ",", "y"}], "]"}], "*", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"m", ">", "0"}], ",", 
        RowBox[{"2", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"Abs", "[", "m", "]"}], "*", "z"}], "]"}]}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"m", "<", "0"}], ",", 
          RowBox[{"2", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"Abs", "[", "m", "]"}], "*", "z"}], "]"}]}], ",", "1"}], 
         "]"}]}], "]"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8417478073134937`*^9, 3.841747809105668*^9}, {
   3.841747856637995*^9, 3.8417479699153147`*^9}, {3.841748021694292*^9, 
   3.841748063528777*^9}, {3.841748102567198*^9, 3.841748164585792*^9}, {
   3.841748376789033*^9, 3.841748428915189*^9}, {3.841811578267119*^9, 
   3.841811591498131*^9}, {3.841889220679842*^9, 3.841889223068616*^9}, 
   3.870937284075032*^9, {3.8709373188446503`*^9, 3.870937342917367*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"e77ebfb3-bcd4-43f6-aee3-8748a8b48a06"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Check", " ", "the", " ", "orthonormality", " ", "of", " ", "f", " ", 
    "and", " ", 
    RowBox[{"fDual", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Ortho", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fBasis", "[", 
         RowBox[{"l1", ",", "l2", ",", "m1", ",", "x", ",", "y", ",", "z"}], 
         "]"}], 
        RowBox[{"fDualBasis", "[", 
         RowBox[{"l3", ",", "l4", ",", "m2", ",", "x", ",", "y", ",", "z"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", 
         RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"l1", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"l2", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m1", ",", 
       RowBox[{"-", 
        RowBox[{"Min", "[", 
         RowBox[{"l1", ",", "l2"}], "]"}]}], ",", 
       RowBox[{"Min", "[", 
        RowBox[{"l1", ",", "l2"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"l3", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"l4", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m2", ",", 
       RowBox[{"-", 
        RowBox[{"Min", "[", 
         RowBox[{"l3", ",", "l4"}], "]"}]}], ",", 
       RowBox[{"Min", "[", 
        RowBox[{"l3", ",", "l4"}], "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.841748173753293*^9, 3.841748235051301*^9}, {
  3.841748433829638*^9, 3.8417485025337543`*^9}, {3.841748560583996*^9, 
  3.8417485786723843`*^9}, {3.841748977169528*^9, 3.841748985496179*^9}, {
  3.84174962154346*^9, 3.841749626489388*^9}, {3.841811604237838*^9, 
  3.841811619772092*^9}, {3.841889227904785*^9, 3.8418892303741093`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"b59ad0c4-d610-4d34-bc03-389a5cf47d42"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"1"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]}
        },
        GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}}], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"1"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]}
        },
        GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}}], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"1"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]}
        },
        GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}}], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "1", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]}
        },
        GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}}], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]},
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]},
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]}
        },
        GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}}], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]},
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]},
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]}
        },
        GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}}], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "1", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]}
        },
        GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}}], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]},
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]},
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]}
        },
        GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}}], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]},
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]},
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], "}"}]}], 
           "}"}]},
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], "}"}]}], 
           "}"}]},
         {
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {"0"},
             {"0"},
             {"0"}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}}], "\[NoBreak]", ")"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "0", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], "}"}]}], 
           "}"}]}
        },
        GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}}], "\[NoBreak]", ")"}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.870937622263493*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"7e23d6fc-ba04-4674-a839-b0fb9654154d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Beneke Results", "Section",
 CellChangeTimes->{{3.870938487539859*^9, 
  3.870938499563101*^9}},ExpressionUUID->"a25ee4c3-de9f-4103-9dd3-\
40afe9ccebbf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "f", 
    RowBox[{
     RowBox[{"(", "...", ")"}], " ", "[", 
     RowBox[{"=", 
      RowBox[{
       SuperscriptBox["d", "5"], "\[CapitalGamma]"}]}], "]"}], " ", "and", 
    " ", 
    SuperscriptBox["d", "2"], "\[CapitalGamma]", " ", "from", " ", "Beneke", 
    " ", "et", " ", 
    RowBox[{"al", ".", " ", 
     RowBox[{"(", "2021", ")"}]}], " ", "and", " ", "its", " ", 
    RowBox[{"quotient", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fBeneke", "=", 
     RowBox[{
      RowBox[{"K1", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]W", "]"}], "2"], 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}], "2"]}], "+", 
      RowBox[{"K2", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]W", "]"}], "2"]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{"K3", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]W", "]"}], "2"], 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}], "2"], 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Phi]", "]"}], "2"]}], "+", 
      RowBox[{"K4", " ", 
       RowBox[{"Cos", "[", "\[Theta]W", "]"}], "*", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"K5", "+", 
         RowBox[{"K6", " ", 
          RowBox[{"Cos", "[", "\[Theta]W", "]"}]}]}], ")"}], 
       RowBox[{"Sin", "[", "\[Theta]W", "]"}], 
       RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}], 
       RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"K7", "+", 
         RowBox[{"K8", " ", 
          RowBox[{"Cos", "[", "\[Theta]W", "]"}]}]}], ")"}], 
       RowBox[{"Sin", "[", "\[Theta]W", "]"}], 
       RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}], 
       RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], 
       RowBox[{"Cos", "[", "\[Phi]", "]"}]}], "+", 
      RowBox[{"K9", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]W", "]"}], "2"], 
       SuperscriptBox[
        RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}], "2"], 
       RowBox[{"Cos", "[", "\[Phi]", "]"}], 
       RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"KRep", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"K1", "\[Rule]", 
        RowBox[{
         FractionBox["1", "4"], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["fAPerp", "2"], "-", 
           SuperscriptBox["fV", "2"], "+", 
           RowBox[{"2", 
            SuperscriptBox["fAPar", "2"]}]}], ")"}]}]}], ",", 
       RowBox[{"K2", "\[Rule]", 
        RowBox[{
         FractionBox["1", "4"], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["fAPerp", "2"], "+", 
           SuperscriptBox["fV", "2"]}], ")"}]}]}], ",", 
       RowBox[{"K3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["fAPerp", "2"], "-", 
           SuperscriptBox["fV", "2"]}], ")"}]}]}], ",", 
       RowBox[{"K4", "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"Re", "[", 
          RowBox[{"fAPerp", "*", "fVCC"}], "]"}]}]}], ",", 
       RowBox[{"K5", "\[Rule]", 
        RowBox[{"Im", "[", 
         RowBox[{"fAPar", "*", "fAPerpCC"}], "]"}]}], ",", 
       RowBox[{"K6", "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"Im", "[", 
          RowBox[{"fAPar", "*", "fVCC"}], "]"}]}]}], ",", 
       RowBox[{"K7", "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"Re", "[", 
          RowBox[{"fAPar", "*", "fVCC"}], "]"}]}]}], ",", 
       RowBox[{"K8", "\[Rule]", 
        RowBox[{"Re", "[", 
         RowBox[{"fAPar", "*", "fAPerpCC"}], "]"}]}], ",", 
       RowBox[{"K9", "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"Im", "[", 
          RowBox[{"fAPerp", "*", "fVCC"}], "]"}]}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FRep", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FAPar", "\[Rule]", 
        FractionBox["fAPar", "\[Lambda]"]}], ",", 
       RowBox[{"FV", "\[Rule]", 
        FractionBox["fV", 
         RowBox[{"2", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["k", "2"], 
            SuperscriptBox["q", "2"], "\[Lambda]"}]]}]]}], ",", 
       RowBox[{"FAPerp", "\[Rule]", 
        FractionBox["fAPerp", 
         RowBox[{"2", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["k", "2"], 
            SuperscriptBox["q", "2"]}]], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["mB", "2"], "-", 
            SuperscriptBox["k", "2"], "+", 
            SuperscriptBox["q", "2"]}], ")"}]}]]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d5\[CapitalGamma]", "=", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["GF", "2"], 
        SuperscriptBox["Vub", "2"], 
        SuperscriptBox["\[Alpha]", "2"]}], 
       RowBox[{
        SuperscriptBox["2", "12"], 
        SuperscriptBox["\[Pi]", "4"], 
        SuperscriptBox["mB", "5"]}]], 
      FractionBox[
       SqrtBox["\[Lambda]"], 
       SuperscriptBox["q", "4"]], 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"4", 
          SuperscriptBox["mlP", "2"]}], 
         SuperscriptBox["q", "2"]]}]], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox[
         SuperscriptBox["ml", "2"], 
         SuperscriptBox["k", "2"]]}], ")"}], "fBeneke"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d2\[CapitalGamma]", "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["GF", "2"], 
         SuperscriptBox["\[Alpha]", "2"], 
         SuperscriptBox["Vub", "2"]}], 
        RowBox[{
         SuperscriptBox["3", "2"], 
         SuperscriptBox["2", "8"], 
         SuperscriptBox["mB", "5"], 
         SuperscriptBox["\[Pi]", "3"], 
         SuperscriptBox["q", "2"]}]], 
       FractionBox[
        SqrtBox["\[Lambda]"], 
        SuperscriptBox["q", "2"]], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["ml", "2"], 
          SuperscriptBox["k", "2"]]}], ")"}], 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"4", 
           SuperscriptBox["mlP", "2"]}], 
          SuperscriptBox["q", "2"]]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Lambda]", "2"], 
          SuperscriptBox["FAPar", "2"]}], "+", 
         RowBox[{"8", 
          SuperscriptBox["k", "2"], 
          SuperscriptBox["q", "2"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["mB", "2"], "-", 
             SuperscriptBox["k", "2"], "+", 
             SuperscriptBox["q", "2"]}], ")"}], "2"], 
          SuperscriptBox["FAPerp", "2"]}], "+", 
         RowBox[{"8", 
          SuperscriptBox["k", "2"], 
          SuperscriptBox["q", "2"], "\[Lambda]", " ", 
          SuperscriptBox["FV", "2"]}]}], ")"}]}], "/.", "FRep"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"d\[CapitalGamma]Quotient", "=", 
    RowBox[{
     FractionBox["d5\[CapitalGamma]", "d2\[CapitalGamma]"], "//", 
     "Simplify"}]}]}]}]], "Input",
 CellChangeTimes->{{3.841746759871016*^9, 3.841747164189683*^9}, {
  3.8417480919595346`*^9, 3.841748094828168*^9}, {3.84174972021795*^9, 
  3.841749723467917*^9}, {3.8417498099737167`*^9, 3.8417499116717663`*^9}, {
  3.8417500891013002`*^9, 3.841750273038433*^9}, {3.841750345650116*^9, 
  3.841750411711965*^9}, {3.8417509336780367`*^9, 3.841750933806716*^9}, {
  3.841811940669999*^9, 3.841811981711767*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"23503bb7-a7a3-4932-8fc8-ddf88acb5883"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"9", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"K1", " ", 
        RowBox[{
         SuperscriptBox["sin", "2"], "(", "\[Theta]\[Gamma]", ")"}], " ", 
        RowBox[{
         SuperscriptBox["sin", "2"], "(", "\[Theta]W", ")"}]}], "+", 
       RowBox[{"K2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["cos", "2"], "(", "\[Theta]\[Gamma]", ")"}], "+", 
          "1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["cos", "2"], "(", "\[Theta]W", ")"}], "+", "1"}], 
         ")"}]}], "+", 
       RowBox[{"K3", " ", 
        RowBox[{
         SuperscriptBox["sin", "2"], "(", "\[Theta]\[Gamma]", ")"}], " ", 
        RowBox[{
         SuperscriptBox["sin", "2"], "(", "\[Theta]W", ")"}], " ", 
        RowBox[{
         SuperscriptBox["sin", "2"], "(", "\[Phi]", ")"}]}], "+", 
       RowBox[{"K4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["cos", "2"], "(", "\[Theta]\[Gamma]", ")"}], "+", 
          "1"}], ")"}], " ", 
        RowBox[{"cos", "(", "\[Theta]W", ")"}]}], "+", 
       RowBox[{
        RowBox[{"sin", "(", "\[Theta]\[Gamma]", ")"}], " ", 
        RowBox[{"cos", "(", "\[Theta]\[Gamma]", ")"}], " ", 
        RowBox[{"sin", "(", "\[Theta]W", ")"}], " ", 
        RowBox[{"sin", "(", "\[Phi]", ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"K5", "+", 
          RowBox[{"K6", " ", 
           RowBox[{"cos", "(", "\[Theta]W", ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"sin", "(", "\[Theta]\[Gamma]", ")"}], " ", 
        RowBox[{"cos", "(", "\[Theta]\[Gamma]", ")"}], " ", 
        RowBox[{"sin", "(", "\[Theta]W", ")"}], " ", 
        RowBox[{"cos", "(", "\[Phi]", ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"K7", "+", 
          RowBox[{"K8", " ", 
           RowBox[{"cos", "(", "\[Theta]W", ")"}]}]}], ")"}]}], "+", 
       RowBox[{"K9", " ", 
        RowBox[{
         SuperscriptBox["sin", "2"], "(", "\[Theta]\[Gamma]", ")"}], " ", 
        RowBox[{
         SuperscriptBox["sin", "2"], "(", "\[Theta]W", ")"}], " ", 
        RowBox[{"sin", "(", "\[Phi]", ")"}], " ", 
        RowBox[{"cos", "(", "\[Phi]", ")"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"16", " ", "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["fAPar", "2"], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["fAPerp", "2"], "+", 
          SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.870938443853657*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"0fc81cae-a6cf-4c31-b803-e606286ac793"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Angular Observables", "Section",
 CellChangeTimes->{{3.87093847419844*^9, 3.870938481755804*^9}, {
  3.870938570646854*^9, 
  3.87093857282384*^9}},ExpressionUUID->"4a10fa8f-15e5-414b-9477-\
e16d6904ea62"],

Cell[CellGroupData[{

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["d", "5"], "\[CapitalGamma]"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "a5b65cfa-8edb-4343-b08c-e3d895d58b7c"]
}], "Subsection",
 CellChangeTimes->{{3.8709385934652157`*^9, 
  3.870938611103016*^9}},ExpressionUUID->"962075c4-b49b-4944-b6bb-\
b6142946f37c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Obtain", " ", "the", " ", "angular", " ", "observables", " ", "S", " ", 
    "in", " ", 
    SuperscriptBox["d", "5"], "\[CapitalGamma]", " ", "by", " ", "projecting",
     " ", "with", " ", "the", " ", "f", " ", "from", " ", 
    RowBox[{"above", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"S000", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"0", ",", "0", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S010", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"0", ",", "1", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S020", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"0", ",", "2", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S100", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "0", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S11M1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "1", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S110", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "1", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S111", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "1", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S12M1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "2", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S120", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "2", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S121", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "2", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S200", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "0", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S21M1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "1", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S210", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "1", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S211", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "1", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S22M2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "2", ",", 
           RowBox[{"-", "2"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S22M1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "2", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S220", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "2", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S221", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "2", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S222", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "2", ",", "2", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}]}]}]], "Input",
 CellChangeTimes->{{3.841749918972402*^9, 3.841750060653466*^9}, {
  3.841750296659626*^9, 3.841750316917386*^9}, {3.841751114873979*^9, 
  3.841751117539459*^9}, {3.84175215192358*^9, 3.84175225846006*^9}, {
  3.841811745271123*^9, 3.841811782887005*^9}, {3.8418118498824263`*^9, 
  3.841811890784361*^9}, {3.841889242965989*^9, 3.8418892630494337`*^9}, {
  3.870938638397225*^9, 3.870938646384275*^9}, {3.870939924541651*^9, 
  3.8709399974556313`*^9}, {3.870940055580452*^9, 3.8709400949348993`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"2e7943a0-8fce-47a1-b51b-42a9ebf0fe09"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SuperscriptBox["GF", "2"], " ", 
    SqrtBox["\[Lambda]"], " ", 
    SuperscriptBox["Vub", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "-", 
      SuperscriptBox["ml", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["mlP", "2"]}], 
       SuperscriptBox["q", "2"]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["fAPar", "2"], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["fAPerp", "2"], "+", 
         SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}], 
   RowBox[{"18432", " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox["mB", "5"], " ", 
    SuperscriptBox["q", "4"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"43deac95-3f47-4a9d-b3f7-8c64b8bdb6c0"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.8709402035724993`*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"a98041d7-a25e-4743-a35c-21c8f65a848c"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SuperscriptBox["GF", "2"], " ", 
    SqrtBox["\[Lambda]"], " ", 
    SuperscriptBox["Vub", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "-", 
      SuperscriptBox["ml", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["mlP", "2"]}], 
       SuperscriptBox["q", "2"]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["fAPar", "2"]}], "+", 
      SuperscriptBox["fAPerp", "2"], "+", 
      SuperscriptBox["fV", "2"]}], ")"}]}], 
   RowBox[{"18432", " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox["mB", "5"], " ", 
    SuperscriptBox["q", "4"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940216284648*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"c5120b61-141c-4b97-8465-6c7eb4b09a3b"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SuperscriptBox["GF", "2"], " ", 
     SqrtBox["\[Lambda]"], " ", 
     SuperscriptBox["Vub", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["ml", "2"], 
        SuperscriptBox["k", "2"]]}], ")"}], " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["mlP", "2"]}], 
        SuperscriptBox["q", "2"]]}]], " ", 
     RowBox[{"Re", "(", 
      RowBox[{"fAPerp", " ", "fVCC"}], ")"}]}], 
    RowBox[{"3072", " ", 
     SuperscriptBox["\[Pi]", "4"], " ", 
     SuperscriptBox["mB", "5"], " ", 
     SuperscriptBox["q", "4"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940224395133*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"ac40e99e-2f2c-4e1c-a7ef-7c96ce4e570a"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940247869735*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"70dcf02b-5574-43ca-a258-21931dd43fa1"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940255563017*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"69825164-6ac5-4fcc-b145-1ab88b06932b"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.8709402742702637`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"db085748-0dae-4dce-94ee-bb43151f4dd9"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SuperscriptBox["GF", "2"], " ", 
    SqrtBox["\[Lambda]"], " ", 
    SuperscriptBox["Vub", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "-", 
      SuperscriptBox["ml", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["mlP", "2"]}], 
       SuperscriptBox["q", "2"]]}]], " ", 
    RowBox[{"Im", "(", 
     RowBox[{"fAPar", " ", "fAPerpCC"}], ")"}]}], 
   RowBox[{"2048", " ", 
    SqrtBox["3"], " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox["mB", "5"], " ", 
    SuperscriptBox["q", "4"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940293590844*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"2eebb914-512e-4d37-b0c8-2beb50f14607"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SuperscriptBox["GF", "2"], " ", 
     SqrtBox["\[Lambda]"], " ", 
     SuperscriptBox["Vub", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["ml", "2"], 
        SuperscriptBox["k", "2"]]}], ")"}], " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["mlP", "2"]}], 
        SuperscriptBox["q", "2"]]}]], " ", 
     RowBox[{"Re", "(", 
      RowBox[{"fAPerp", " ", "fVCC"}], ")"}]}], 
    RowBox[{"6144", " ", 
     SuperscriptBox["\[Pi]", "4"], " ", 
     SuperscriptBox["mB", "5"], " ", 
     SuperscriptBox["q", "4"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.8709403020410633`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"07c36cae-a2ce-4d9a-aa2d-3e74a57f1a73"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SuperscriptBox["GF", "2"], " ", 
     SqrtBox["\[Lambda]"], " ", 
     SuperscriptBox["Vub", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "-", 
       SuperscriptBox["ml", "2"]}], ")"}], " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["mlP", "2"]}], 
        SuperscriptBox["q", "2"]]}]], " ", 
     RowBox[{"Re", "(", 
      RowBox[{"fAPar", " ", "fVCC"}], ")"}]}], 
    RowBox[{"2048", " ", 
     SqrtBox["3"], " ", 
     SuperscriptBox["\[Pi]", "4"], " ", 
     SuperscriptBox["k", "2"], " ", 
     SuperscriptBox["mB", "5"], " ", 
     SuperscriptBox["q", "4"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940321561064*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"c1ff56b2-7d03-4b62-8b39-a165a6c917e9"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SuperscriptBox["GF", "2"], " ", 
    SqrtBox["\[Lambda]"], " ", 
    SuperscriptBox["Vub", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "-", 
      SuperscriptBox["ml", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["mlP", "2"]}], 
       SuperscriptBox["q", "2"]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["fAPar", "2"]}], "+", 
      SuperscriptBox["fAPerp", "2"], "+", 
      SuperscriptBox["fV", "2"]}], ")"}]}], 
   RowBox[{"18432", " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox["mB", "5"], " ", 
    SuperscriptBox["q", "4"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940337285018*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"76838b10-cc60-412e-9078-04917a589278"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940354069655*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"ae494889-2dac-47a8-af4d-c427742e358a"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940368449849*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"17d47aa6-9a51-4046-992d-bd018d004ce8"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940386611993*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"73c8709f-192b-404c-bc5e-9c1a3f3ef967"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SuperscriptBox["GF", "2"], " ", 
     SqrtBox["\[Lambda]"], " ", 
     SuperscriptBox["Vub", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "-", 
       SuperscriptBox["ml", "2"]}], ")"}], " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["mlP", "2"]}], 
        SuperscriptBox["q", "2"]]}]], " ", 
     RowBox[{"Im", "(", 
      RowBox[{"fAPerp", " ", "fVCC"}], ")"}]}], 
    RowBox[{"3072", " ", 
     SuperscriptBox["\[Pi]", "4"], " ", 
     SuperscriptBox["k", "2"], " ", 
     SuperscriptBox["mB", "5"], " ", 
     SuperscriptBox["q", "4"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940413436499*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"69ddfcd2-1639-48a4-8547-bb52775125fe"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Alpha]", "2"], " ", 
     SuperscriptBox["GF", "2"], " ", 
     SqrtBox["\[Lambda]"], " ", 
     SuperscriptBox["Vub", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "-", 
       SuperscriptBox["ml", "2"]}], ")"}], " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["mlP", "2"]}], 
        SuperscriptBox["q", "2"]]}]], " ", 
     RowBox[{"Im", "(", 
      RowBox[{"fAPar", " ", "fVCC"}], ")"}]}], 
    RowBox[{"6144", " ", 
     SuperscriptBox["\[Pi]", "4"], " ", 
     SuperscriptBox["k", "2"], " ", 
     SuperscriptBox["mB", "5"], " ", 
     SuperscriptBox["q", "4"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940430573885*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"564e4958-414c-4789-825f-23b9374083b4"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SuperscriptBox["GF", "2"], " ", 
    SqrtBox["\[Lambda]"], " ", 
    SuperscriptBox["Vub", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "-", 
      SuperscriptBox["ml", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["mlP", "2"]}], 
       SuperscriptBox["q", "2"]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["fAPar", "2"]}], "+", 
      SuperscriptBox["fAPerp", "2"], "+", 
      SuperscriptBox["fV", "2"]}], ")"}]}], 
   RowBox[{"36864", " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox["mB", "5"], " ", 
    SuperscriptBox["q", "4"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940447686432*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"bb58655f-54d7-4f8e-9f13-8e03340892e9"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SuperscriptBox["GF", "2"], " ", 
    SqrtBox["\[Lambda]"], " ", 
    SuperscriptBox["Vub", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "-", 
      SuperscriptBox["ml", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["mlP", "2"]}], 
       SuperscriptBox["q", "2"]]}]], " ", 
    RowBox[{"Re", "(", 
     RowBox[{"fAPar", " ", "fAPerpCC"}], ")"}]}], 
   RowBox[{"6144", " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox["mB", "5"], " ", 
    SuperscriptBox["q", "4"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940465253282*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"139350dc-3d83-4965-bfda-85f8a826a8fc"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Alpha]", "2"], " ", 
    SuperscriptBox["GF", "2"], " ", 
    SqrtBox["\[Lambda]"], " ", 
    SuperscriptBox["Vub", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["fAPerp", "2"], "-", 
      SuperscriptBox["fV", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "-", 
      SuperscriptBox["ml", "2"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["mlP", "2"]}], 
       SuperscriptBox["q", "2"]]}]]}], 
   RowBox[{"6144", " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox["mB", "5"], " ", 
    SuperscriptBox["q", "4"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.870940491730957*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"bee4655c-8cea-44e3-87b4-6f2ffe92a699"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Note", " ", "that", " ", "the", " ", "\"\<next\>\"", " ", "possible", " ",
     "terms", " ", "vanish", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "which", " ", "should", " ", "continue", " ", "to", " ", "hold", " ", 
       "for", " ", "even", " ", "higher", " ", "ones"}], ")"}], "."}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"S030", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"0", ",", "3", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S13M1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "3", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S130", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "3", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S131", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "3", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S31M1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "1", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S310", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "1", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S311", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "1", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S23M2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "3", ",", 
           RowBox[{"-", "2"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S23M1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "3", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S230", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "3", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S231", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "3", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S232", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "3", ",", "2", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S32M2", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "2", ",", 
           RowBox[{"-", "2"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S32M1", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "2", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S320", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "2", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S321", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "2", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S322", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d5\[CapitalGamma]", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "2", ",", "2", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}]}]}]], "Input",
 CellChangeTimes->{{3.841752270958178*^9, 3.841752332808325*^9}, {
  3.841752380594591*^9, 3.841752478493765*^9}, {3.8418119012995367`*^9, 
  3.841811917862441*^9}, {3.841812016928393*^9, 3.841812029352106*^9}, {
  3.841889265776309*^9, 3.841889281969367*^9}, {3.8709400020972137`*^9, 
  3.870940039046177*^9}, {3.870940100463255*^9, 3.870940129368937*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"428ea2db-e757-4293-8cba-0871add612e3"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"09123b31-9fce-4fa4-8b3d-5f126c718d6d"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.870940564360222*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"257e529b-ad10-4ba2-9c44-b36f5cdda303"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.870940573941572*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"aaa29b5d-507b-44eb-8c2e-f954cbf2b8a9"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.870940592241996*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"f58c21ee-af17-4bb0-94ac-80b805872853"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.870940606682789*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"fe9f18dc-b16b-47bd-89e1-c0f1cba950ab"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709406167334127`*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"eea5df53-1ffb-49ba-b810-0312ab8931a9"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.870940632532607*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"8ee3a76e-2fd5-4591-be83-faf878b7e56d"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709406586904488`*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"202cef7c-bfd1-42c8-896e-f8342ae284be"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.870940677086116*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"d781c6a6-2606-4a6e-86e3-6284b5cae876"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709406988439903`*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"ce068351-b542-49f2-bee4-255735a95ddb"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709407230930853`*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"16441b4d-3ece-445e-87cb-80dd2400aa48"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709407488196583`*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"2b925880-13f2-42c4-a6d3-0c7e82f27d42"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709407702648497`*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"613db659-8015-421c-9ef6-eba8fcef20d6"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.870940784972129*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"9956578e-8f8c-47fb-aebb-94fbb29a9e3a"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.870940797245183*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"9d2eac1e-f974-457d-add2-3c198be2f763"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709408137175817`*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"59451d0b-bdbe-462d-8f55-22218f6ba216"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.870940833545677*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"fdd4f0e3-0109-4fa7-9b03-1b1792c1356e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["d", "5"], 
    RowBox[{"\[CapitalGamma]", "/", 
     SuperscriptBox["d", "2"]}], "\[CapitalGamma]"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "37ba5ac7-057d-478b-a57a-c61f76b5f8fc"]
}], "Subsection",
 CellChangeTimes->{{3.8709385934652157`*^9, 3.870938611103016*^9}, {
  3.870940873003717*^9, 
  3.870940875731758*^9}},ExpressionUUID->"ef5fc85d-eb47-4bc2-abdc-\
dcf5096b89cd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Obtain", " ", "the", " ", "angular", " ", "observables", " ", "S", " ", 
    "in", " ", 
    SuperscriptBox["d", "5"], "\[CapitalGamma]", " ", "by", " ", "projecting",
     " ", "with", " ", "the", " ", "f", " ", "from", " ", 
    RowBox[{"above", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"S000Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"0", ",", "0", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S010Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"0", ",", "1", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S020Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"0", ",", "2", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S100Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "0", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S11M1Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "1", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S110Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "1", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S111Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "1", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S12M1Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "2", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S120Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "2", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S121Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "2", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S200Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "0", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S21M1Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "1", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S210Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "1", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S211Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "1", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S22M2Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "2", ",", 
           RowBox[{"-", "2"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S22M1Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "2", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S220Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "2", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S221Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "2", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S222Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "2", ",", "2", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}]}]}]], "Input",
 CellChangeTimes->{{3.841749918972402*^9, 3.841750060653466*^9}, {
  3.841750296659626*^9, 3.841750316917386*^9}, {3.841751114873979*^9, 
  3.841751117539459*^9}, {3.84175215192358*^9, 3.84175225846006*^9}, {
  3.841811745271123*^9, 3.841811782887005*^9}, {3.8418118498824263`*^9, 
  3.841811890784361*^9}, {3.841889242965989*^9, 3.8418892630494337`*^9}, {
  3.870938638397225*^9, 3.870938646384275*^9}, {3.870939924541651*^9, 
  3.8709399974556313`*^9}, {3.870940055580452*^9, 3.8709400949348993`*^9}, {
  3.870940880772389*^9, 3.870940919166606*^9}, {3.87094095854307*^9, 
  3.870940975864812*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"cc664616-984b-446e-9d29-eb32ea9786fc"],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{"8", " ", "\[Pi]"}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941010884243*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"42fdb214-b5bf-47b7-b649-4bdfbf27039f"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941018234597*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"ac9c0f44-9a4a-497e-9d0e-34f4f46f8726"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["fAPar", "2"]}], "+", 
    SuperscriptBox["fAPerp", "2"], "+", 
    SuperscriptBox["fV", "2"]}], 
   RowBox[{"8", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["fAPar", "2"], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["fAPerp", "2"], "+", 
         SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941027717947*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"a575eb98-df64-4c02-bb04-cfc2918c55f6"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"Re", "(", 
      RowBox[{"fAPerp", " ", "fVCC"}], ")"}]}], 
    RowBox[{"4", " ", "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["fAPar", "2"], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["fAPerp", "2"], "+", 
          SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941033951339*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"c9c2ea44-f797-4b56-beb8-68c1a6f3b08e"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941048173499*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"7383f135-810f-437c-906b-c5dbc3e3f0da"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941054284532*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"5748ba43-c74f-4c34-818f-c57971fd53ff"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941068329121*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"1c2716a7-12d3-4d0b-92f1-d56723d24c72"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"3", " ", 
    SqrtBox["3"], " ", 
    RowBox[{"Im", "(", 
     RowBox[{"fAPar", " ", "fAPerpCC"}], ")"}]}], 
   RowBox[{"8", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["fAPar", "2"], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["fAPerp", "2"], "+", 
         SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941081022395*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"6f3601ad-a535-4431-bfc3-ee0a07713a79"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"Re", "(", 
      RowBox[{"fAPerp", " ", "fVCC"}], ")"}]}], 
    RowBox[{"8", " ", "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["fAPar", "2"], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["fAPerp", "2"], "+", 
          SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941086707765*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"6ce367d2-848b-4a15-9a92-4052d64ceff5"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     SqrtBox["3"], " ", 
     RowBox[{"Re", "(", 
      RowBox[{"fAPar", " ", "fVCC"}], ")"}]}], 
    RowBox[{"8", " ", "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["fAPar", "2"], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["fAPerp", "2"], "+", 
          SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941102544887*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"8fc4b154-f5d2-4691-9542-8025f18f12f2"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["fAPar", "2"]}], "+", 
    SuperscriptBox["fAPerp", "2"], "+", 
    SuperscriptBox["fV", "2"]}], 
   RowBox[{"8", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["fAPar", "2"], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["fAPerp", "2"], "+", 
         SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.8709411172456636`*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"87b3b048-cc7b-40c6-8cad-9747e88f21a5"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941130052087*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"e2e97b1f-2966-4446-8ab0-b5f61d573b4b"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.8709411430658007`*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"8c228b49-715f-4f84-9f62-8593c978f6f8"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941155698262*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"f62d86bf-9364-44b8-8e19-b67bf2dd1f38"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"Im", "(", 
      RowBox[{"fAPerp", " ", "fVCC"}], ")"}]}], 
    RowBox[{"4", " ", "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["fAPar", "2"], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["fAPerp", "2"], "+", 
          SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941171576808*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"4cb4850c-3d70-4f16-bc02-7b4f25d4de8c"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"Im", "(", 
      RowBox[{"fAPar", " ", "fVCC"}], ")"}]}], 
    RowBox[{"8", " ", "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["fAPar", "2"], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["fAPerp", "2"], "+", 
          SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941185357996*^9},
 CellLabel->"Out[63]=",ExpressionUUID->"058d886b-5375-4001-abbb-20238533d0af"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["fAPar", "2"]}], "+", 
    SuperscriptBox["fAPerp", "2"], "+", 
    SuperscriptBox["fV", "2"]}], 
   RowBox[{"16", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["fAPar", "2"], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["fAPerp", "2"], "+", 
         SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.8709411987345953`*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"1a615144-d08c-408e-97c0-92e33823c03c"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{"Re", "(", 
     RowBox[{"fAPar", " ", "fAPerpCC"}], ")"}]}], 
   RowBox[{"8", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["fAPar", "2"], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["fAPerp", "2"], "+", 
         SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941213268076*^9},
 CellLabel->"Out[65]=",ExpressionUUID->"07ad2242-9079-44d9-883f-36b8488f3e3b"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["fAPerp", "2"], "-", 
      SuperscriptBox["fV", "2"]}], ")"}]}], 
   RowBox[{"8", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["fAPar", "2"], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["fAPerp", "2"], "+", 
         SuperscriptBox["fV", "2"]}], ")"}]}]}], ")"}]}]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8417500688719673`*^9, {3.8417502888680468`*^9, 3.841750324617264*^9}, 
   3.8417509476426153`*^9, 3.841751124386344*^9, 3.8417524953637753`*^9, 
   3.841889428357335*^9, 3.87094019355062*^9, 3.870941232520924*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"74c5a492-ad5b-4427-8fbe-6a5707660f75"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Note", " ", "that", " ", "the", " ", "\"\<next\>\"", " ", "possible", " ",
     "terms", " ", "vanish", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "which", " ", "should", " ", "continue", " ", "to", " ", "hold", " ", 
       "for", " ", "even", " ", "higher", " ", "ones"}], ")"}], "."}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"S030Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"0", ",", "3", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S13M1Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "3", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S130Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "3", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S131Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"1", ",", "3", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S31M1Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "1", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S310Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "1", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S311Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "1", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S23M2Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "3", ",", 
           RowBox[{"-", "2"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S23M1Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "3", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S230Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "3", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S231Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "3", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S232Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"2", ",", "3", ",", "2", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"S32M2Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "2", ",", 
           RowBox[{"-", "2"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S32M1Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "2", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S320Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "2", ",", "0", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S321Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "2", ",", "1", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"S322Quotient", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"d\[CapitalGamma]Quotient", "*", 
         RowBox[{"fDualBasis", "[", 
          RowBox[{"3", ",", "2", ",", "2", ",", 
           RowBox[{"Cos", "[", "\[Theta]W", "]"}], ",", 
           RowBox[{"Cos", "[", "\[Theta]\[Gamma]", "]"}], ",", "\[Phi]"}], 
          "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]W", "]"}], "*", 
         RowBox[{"Sin", "[", "\[Theta]\[Gamma]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]\[Gamma]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]W", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]", ",", "0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/.", "KRep"}], "//", 
     "Simplify"}]}]}]}]], "Input",
 CellChangeTimes->{{3.841752270958178*^9, 3.841752332808325*^9}, {
  3.841752380594591*^9, 3.841752478493765*^9}, {3.8418119012995367`*^9, 
  3.841811917862441*^9}, {3.841812016928393*^9, 3.841812029352106*^9}, {
  3.841889265776309*^9, 3.841889281969367*^9}, {3.8709400020972137`*^9, 
  3.870940039046177*^9}, {3.870940100463255*^9, 3.870940129368937*^9}, {
  3.870940923441102*^9, 3.870940939724082*^9}, {3.870940981964808*^9, 
  3.8709409918354053`*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"408660d9-d6d3-4a79-8102-59de0b4a2afa"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941240436863*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"4f8a062e-8ecd-4352-be9b-2404cd7772cb"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941253790056*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"17876912-294e-4913-b8ad-377ceea8d6fe"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941260455421*^9},
 CellLabel->"Out[69]=",ExpressionUUID->"27aa20ee-2299-4e1d-af97-41cfa19e6a79"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941282847733*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"7df9f707-717c-4049-9486-cab691f82389"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941295466352*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"3331db41-686e-42f3-a6f3-73e618d985d3"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.8709413047066593`*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"03f55674-6d7c-4f88-83dc-b9f4ebe01a03"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941318626446*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"3c6511a6-b980-4342-a03e-919d053b8e5d"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.8709413354431067`*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"5736b801-cf93-4cd8-9dae-f7608dc10965"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.8709413506893377`*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"e571b653-b81d-4b23-8cbb-5bc5f5c28aec"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941364265997*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"763b3a87-f222-408f-b561-55a873509866"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941381079133*^9},
 CellLabel->"Out[77]=",ExpressionUUID->"dc954505-3d68-4b0d-9e7f-426874698677"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941397053838*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"09eb6f17-1ce4-45e8-838e-7de2a2c80797"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941413388831*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"a25eb1a6-4135-4021-8d0c-f23aeb6798be"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941426462824*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"d7b9efc1-6c30-4ca0-98be-20de09e9d280"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.870941435030623*^9},
 CellLabel->"Out[81]=",ExpressionUUID->"a80c3526-6358-491b-9b33-9cec1dc2804e"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.8709414506932697`*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"0ff4f8ee-f030-4c85-b26f-1b55c42fbbea"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8709405481491213`*^9, 3.8709414678556004`*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"a16f23c7-b812-47bc-ae2d-ba5bb752ad5c"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1366, 647},
WindowMargins->{{-1357, Automatic}, {-82, Automatic}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 179, 3, 97, "Title",ExpressionUUID->"9c4b7cfd-96e6-4537-935d-10cfac86b5e7"],
Cell[762, 27, 966, 24, 63, "Input",ExpressionUUID->"d1175880-9af7-46d5-8a9b-c1aecb0755de"],
Cell[CellGroupData[{
Cell[1753, 55, 242, 4, 69, "Section",ExpressionUUID->"b9e2f608-af7d-414b-8e86-fb4770a02cc1"],
Cell[1998, 61, 8074, 245, 354, "Input",ExpressionUUID->"e77ebfb3-bcd4-43f6-aee3-8748a8b48a06"],
Cell[CellGroupData[{
Cell[10097, 310, 2138, 55, 84, "Input",ExpressionUUID->"b59ad0c4-d610-4d34-bc03-389a5cf47d42"],
Cell[12238, 367, 25139, 695, 493, "Output",ExpressionUUID->"7e23d6fc-ba04-4674-a839-b0fb9654154d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37426, 1068, 159, 3, 69, "Section",ExpressionUUID->"a25ee4c3-de9f-4103-9dd3-40afe9ccebbf"],
Cell[CellGroupData[{
Cell[37610, 1075, 8242, 235, 401, "Input",ExpressionUUID->"23503bb7-a7a3-4932-8fc8-ddf88acb5883"],
Cell[45855, 1312, 2784, 74, 73, "Output",ExpressionUUID->"0fc81cae-a6cf-4c31-b803-e606286ac793"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48688, 1392, 211, 4, 69, "Section",ExpressionUUID->"4a10fa8f-15e5-414b-9477-e16d6904ea62"],
Cell[CellGroupData[{
Cell[48924, 1400, 369, 11, 34, "Subsection",ExpressionUUID->"962075c4-b49b-4944-b6bb-b6142946f37c"],
Cell[CellGroupData[{
Cell[49318, 1415, 17964, 421, 609, "Input",ExpressionUUID->"2e7943a0-8fce-47a1-b51b-42a9ebf0fe09"],
Cell[67285, 1838, 1220, 35, 85, "Output",ExpressionUUID->"43deac95-3f47-4a9d-b3f7-8c64b8bdb6c0"],
Cell[68508, 1875, 354, 6, 37, "Output",ExpressionUUID->"a98041d7-a25e-4743-a35c-21c8f65a848c"],
Cell[68865, 1883, 1164, 33, 85, "Output",ExpressionUUID->"c5120b61-141c-4b97-8465-6c7eb4b09a3b"],
Cell[70032, 1918, 1082, 30, 85, "Output",ExpressionUUID->"ac40e99e-2f2c-4e1c-a7ef-7c96ce4e570a"],
Cell[71117, 1950, 352, 6, 37, "Output",ExpressionUUID->"70dcf02b-5574-43ca-a258-21931dd43fa1"],
Cell[71472, 1958, 352, 6, 37, "Output",ExpressionUUID->"69825164-6ac5-4fcc-b145-1ab88b06932b"],
Cell[71827, 1966, 354, 6, 37, "Output",ExpressionUUID->"db085748-0dae-4dce-94ee-bb43151f4dd9"],
Cell[72184, 1974, 1077, 30, 85, "Output",ExpressionUUID->"2eebb914-512e-4d37-b0c8-2beb50f14607"],
Cell[73264, 2006, 1084, 30, 85, "Output",ExpressionUUID->"07c36cae-a2ce-4d9a-aa2d-3e74a57f1a73"],
Cell[74351, 2038, 1115, 31, 85, "Output",ExpressionUUID->"c1ff56b2-7d03-4b62-8b39-a165a6c917e9"],
Cell[75469, 2071, 1164, 33, 85, "Output",ExpressionUUID->"76838b10-cc60-412e-9078-04917a589278"],
Cell[76636, 2106, 352, 6, 37, "Output",ExpressionUUID->"ae494889-2dac-47a8-af4d-c427742e358a"],
Cell[76991, 2114, 352, 6, 37, "Output",ExpressionUUID->"17d47aa6-9a51-4046-992d-bd018d004ce8"],
Cell[77346, 2122, 352, 6, 37, "Output",ExpressionUUID->"73c8709f-192b-404c-bc5e-9c1a3f3ef967"],
Cell[77701, 2130, 1091, 30, 85, "Output",ExpressionUUID->"69ddfcd2-1639-48a4-8547-bb52775125fe"],
Cell[78795, 2162, 1090, 30, 85, "Output",ExpressionUUID->"564e4958-414c-4789-825f-23b9374083b4"],
Cell[79888, 2194, 1169, 33, 85, "Output",ExpressionUUID->"bb58655f-54d7-4f8e-9f13-8e03340892e9"],
Cell[81060, 2229, 1053, 29, 85, "Output",ExpressionUUID->"139350dc-3d83-4965-bfda-85f8a826a8fc"],
Cell[82116, 2260, 1098, 31, 85, "Output",ExpressionUUID->"bee4655c-8cea-44e3-87b4-6f2ffe92a699"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83251, 2296, 16050, 381, 483, "Input",ExpressionUUID->"428ea2db-e757-4293-8cba-0871add612e3"],
Cell[99304, 2679, 179, 3, 37, "Output",ExpressionUUID->"09123b31-9fce-4fa4-8b3d-5f126c718d6d"],
Cell[99486, 2684, 177, 3, 37, "Output",ExpressionUUID->"257e529b-ad10-4ba2-9c44-b36f5cdda303"],
Cell[99666, 2689, 177, 3, 37, "Output",ExpressionUUID->"aaa29b5d-507b-44eb-8c2e-f954cbf2b8a9"],
Cell[99846, 2694, 177, 3, 37, "Output",ExpressionUUID->"f58c21ee-af17-4bb0-94ac-80b805872853"],
Cell[100026, 2699, 177, 3, 37, "Output",ExpressionUUID->"fe9f18dc-b16b-47bd-89e1-c0f1cba950ab"],
Cell[100206, 2704, 179, 3, 37, "Output",ExpressionUUID->"eea5df53-1ffb-49ba-b810-0312ab8931a9"],
Cell[100388, 2709, 177, 3, 37, "Output",ExpressionUUID->"8ee3a76e-2fd5-4591-be83-faf878b7e56d"],
Cell[100568, 2714, 179, 3, 37, "Output",ExpressionUUID->"202cef7c-bfd1-42c8-896e-f8342ae284be"],
Cell[100750, 2719, 177, 3, 37, "Output",ExpressionUUID->"d781c6a6-2606-4a6e-86e3-6284b5cae876"],
Cell[100930, 2724, 179, 3, 37, "Output",ExpressionUUID->"ce068351-b542-49f2-bee4-255735a95ddb"],
Cell[101112, 2729, 179, 3, 37, "Output",ExpressionUUID->"16441b4d-3ece-445e-87cb-80dd2400aa48"],
Cell[101294, 2734, 179, 3, 37, "Output",ExpressionUUID->"2b925880-13f2-42c4-a6d3-0c7e82f27d42"],
Cell[101476, 2739, 179, 3, 37, "Output",ExpressionUUID->"613db659-8015-421c-9ef6-eba8fcef20d6"],
Cell[101658, 2744, 177, 3, 37, "Output",ExpressionUUID->"9956578e-8f8c-47fb-aebb-94fbb29a9e3a"],
Cell[101838, 2749, 177, 3, 37, "Output",ExpressionUUID->"9d2eac1e-f974-457d-add2-3c198be2f763"],
Cell[102018, 2754, 179, 3, 37, "Output",ExpressionUUID->"59451d0b-bdbe-462d-8f55-22218f6ba216"],
Cell[102200, 2759, 177, 3, 37, "Output",ExpressionUUID->"fdd4f0e3-0109-4fa7-9b03-1b1792c1356e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[102426, 2768, 489, 14, 37, "Subsection",ExpressionUUID->"ef5fc85d-eb47-4bc2-abdc-dcf5096b89cd"],
Cell[CellGroupData[{
Cell[102940, 2786, 18346, 423, 609, "Input",ExpressionUUID->"cc664616-984b-446e-9d29-eb32ea9786fc"],
Cell[121289, 3211, 422, 8, 58, "Output",ExpressionUUID->"42fdb214-b5bf-47b7-b649-4bdfbf27039f"],
Cell[121714, 3221, 373, 6, 37, "Output",ExpressionUUID->"ac9c0f44-9a4a-497e-9d0e-34f4f46f8726"],
Cell[122090, 3229, 813, 22, 66, "Output",ExpressionUUID->"a575eb98-df64-4c02-bb04-cfc2918c55f6"],
Cell[122906, 3253, 790, 21, 63, "Output",ExpressionUUID->"c9c2ea44-f797-4b56-beb8-68c1a6f3b08e"],
Cell[123699, 3276, 373, 6, 37, "Output",ExpressionUUID->"7383f135-810f-437c-906b-c5dbc3e3f0da"],
Cell[124075, 3284, 373, 6, 37, "Output",ExpressionUUID->"5748ba43-c74f-4c34-818f-c57971fd53ff"],
Cell[124451, 3292, 373, 6, 37, "Output",ExpressionUUID->"1c2716a7-12d3-4d0b-92f1-d56723d24c72"],
Cell[124827, 3300, 786, 21, 67, "Output",ExpressionUUID->"6f3601ad-a535-4431-bfc3-ee0a07713a79"],
Cell[125616, 3323, 790, 21, 63, "Output",ExpressionUUID->"6ce367d2-848b-4a15-9a92-4052d64ceff5"],
Cell[126409, 3346, 814, 22, 67, "Output",ExpressionUUID->"8fc4b154-f5d2-4691-9542-8025f18f12f2"],
Cell[127226, 3370, 815, 22, 66, "Output",ExpressionUUID->"87b3b048-cc7b-40c6-8cad-9747e88f21a5"],
Cell[128044, 3394, 373, 6, 37, "Output",ExpressionUUID->"e2e97b1f-2966-4446-8ab0-b5f61d573b4b"],
Cell[128420, 3402, 375, 6, 37, "Output",ExpressionUUID->"8c228b49-715f-4f84-9f62-8593c978f6f8"],
Cell[128798, 3410, 373, 6, 37, "Output",ExpressionUUID->"f62d86bf-9364-44b8-8e19-b67bf2dd1f38"],
Cell[129174, 3418, 790, 21, 63, "Output",ExpressionUUID->"4cb4850c-3d70-4f16-bc02-7b4f25d4de8c"],
Cell[129967, 3441, 789, 21, 63, "Output",ExpressionUUID->"058d886b-5375-4001-abbb-20238533d0af"],
Cell[130759, 3464, 821, 22, 66, "Output",ExpressionUUID->"1a615144-d08c-408e-97c0-92e33823c03c"],
Cell[131583, 3488, 762, 20, 63, "Output",ExpressionUUID->"07ad2242-9079-44d9-883f-36b8488f3e3b"],
Cell[132348, 3510, 807, 22, 67, "Output",ExpressionUUID->"74c5a492-ad5b-4427-8fbe-6a5707660f75"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133192, 3537, 16405, 383, 483, "Input",ExpressionUUID->"408660d9-d6d3-4a79-8102-59de0b4a2afa"],
Cell[149600, 3922, 201, 3, 37, "Output",ExpressionUUID->"4f8a062e-8ecd-4352-be9b-2404cd7772cb"],
Cell[149804, 3927, 201, 3, 37, "Output",ExpressionUUID->"17876912-294e-4913-b8ad-377ceea8d6fe"],
Cell[150008, 3932, 201, 3, 37, "Output",ExpressionUUID->"27aa20ee-2299-4e1d-af97-41cfa19e6a79"],
Cell[150212, 3937, 201, 3, 37, "Output",ExpressionUUID->"7df9f707-717c-4049-9486-cab691f82389"],
Cell[150416, 3942, 201, 3, 37, "Output",ExpressionUUID->"3331db41-686e-42f3-a6f3-73e618d985d3"],
Cell[150620, 3947, 203, 3, 37, "Output",ExpressionUUID->"03f55674-6d7c-4f88-83dc-b9f4ebe01a03"],
Cell[150826, 3952, 201, 3, 37, "Output",ExpressionUUID->"3c6511a6-b980-4342-a03e-919d053b8e5d"],
Cell[151030, 3957, 203, 3, 37, "Output",ExpressionUUID->"5736b801-cf93-4cd8-9dae-f7608dc10965"],
Cell[151236, 3962, 203, 3, 37, "Output",ExpressionUUID->"e571b653-b81d-4b23-8cbb-5bc5f5c28aec"],
Cell[151442, 3967, 201, 3, 37, "Output",ExpressionUUID->"763b3a87-f222-408f-b561-55a873509866"],
Cell[151646, 3972, 201, 3, 37, "Output",ExpressionUUID->"dc954505-3d68-4b0d-9e7f-426874698677"],
Cell[151850, 3977, 201, 3, 37, "Output",ExpressionUUID->"09eb6f17-1ce4-45e8-838e-7de2a2c80797"],
Cell[152054, 3982, 201, 3, 37, "Output",ExpressionUUID->"a25eb1a6-4135-4021-8d0c-f23aeb6798be"],
Cell[152258, 3987, 201, 3, 37, "Output",ExpressionUUID->"d7b9efc1-6c30-4ca0-98be-20de09e9d280"],
Cell[152462, 3992, 201, 3, 37, "Output",ExpressionUUID->"a80c3526-6358-491b-9b33-9cec1dc2804e"],
Cell[152666, 3997, 203, 3, 37, "Output",ExpressionUUID->"0ff4f8ee-f030-4c85-b26f-1b55c42fbbea"],
Cell[152872, 4002, 203, 3, 37, "Output",ExpressionUUID->"a16f23c7-b812-47bc-ae2d-ba5bb752ad5c"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

